@@ -1,4 +1,4 @@
-from .dolt import Dolt, DoltException, DoltCommit
+from .dolt import Dolt, DoltException, DoltCommit, ServerConfig
 from .system_helpers import LOG_LEVEL, HANDLERS, register_cleanup
 
 register_cleanup()
