@@ -2,8 +2,7 @@ import logging
 import atexit
 import psutil
 
-
-LOG_LEVEL = logging.WARN
+LOG_LEVEL = logging.INFO
 logger = logging.getLogger()
 logger.setLevel(LOG_LEVEL)
 HANDLERS = []
