@@ -1,15 +1,15 @@
-from .dolthub_loader import main as dolthub_loader_main, loader as dolthub_loader
-from .dolt_loader import main as dolt_loader_main, loader as dolt_loader
+from .wrappers import load_to_dolt, load_to_dolthub
 from .loaders import (get_df_table_writer,
                       get_bulk_table_writer,
                       get_unique_key_table_writer,
                       get_dolt_loader,
                       get_branch_creator,
-                      get_table_transfomer,
+                      get_table_transformer,
                       insert_unique_key,
-                      resolve_function,
                       create_table_from_schema_import,
                       create_table_from_schema_import_unique_key,
                       DoltTableWriter,
-                      DoltLoader,
-                      DoltLoaderBuilder)
+                      DoltLoader)
+from ..core.system_helpers import register_cleanup
+
+register_cleanup()
