@@ -1,10 +1,10 @@
-from .sync_tools import sync_from_dolt, sync_to_dolt
+from .sync_tools import sync_from_dolt, sync_to_dolt, sync_schema_to_dolt
 from .dolt import (get_source_reader as get_dolt_source_reader,
                    get_table_reader as get_dolt_table_reader,
                    get_table_reader_diffs as get_dolt_table_reader_diffs,
                    get_target_writer as get_dolt_target_writer)
-from .mysql import get_target_writer as get_mysql_target_writer
-from .postgres import get_target_writer as get_postgres_target_writer
+from .mysql import get_target_writer as get_mysql_target_writer, MYSQL_TO_DOLT_TYPE_MAPPINGS
+from .postgres import get_target_writer as get_postgres_target_writer, POSTGRES_TO_DOLT_TYPE_MAPPINGS
 from .db_tools import (get_source_reader as get_mysql_source_reader,
                        get_source_reader as get_postgres_source_reader,
                        get_table_reader)
