@@ -6,12 +6,14 @@ from doltpy.etl.sql_sync.db_tools import (get_table_metadata,
                                           DoltAsSourceReader,
                                           DoltAsSourceUpdate,
                                           DoltAsTargetUpdate,
-                                          drop_primary_keys)
+                                          drop_primary_keys,
+                                          hash_row_els)
 from doltpy.etl.sql_sync.mysql import clean_types
 from typing import List, Callable, Tuple, Mapping
 from datetime import datetime
 from sqlalchemy.engine import Engine
 from sqlalchemy import Table, select, bindparam, MetaData
+from copy import deepcopy
 
 logger = get_logger(__name__)
 
@@ -31,7 +33,7 @@ def get_target_writer(repo: Dolt, branch: str = None, commit: bool = True, messa
         if branch and branch != current_branch:
             repo.checkout(branch)
 
-        engine = repo.engine
+        engine = repo.get_engine()
         metadata = MetaData(bind=engine)
         metadata.reflect()
 
@@ -42,8 +44,8 @@ def get_target_writer(repo: Dolt, branch: str = None, commit: bool = True, messa
             write_to_table(repo, table, list(data), False)
 
         if commit and not repo.status().is_clean:
-            for table, _ in table_data_map.items():
-                repo.add(table)
+            for table_name, _ in table_data_map.items():
+                repo.add(str(table_name))
             commit_message = message or 'Execute write for sync to Dolt'
             repo.commit(commit_message)
 
@@ -108,7 +110,7 @@ def get_source_reader(repo: Dolt, reader: Callable[[str, Dolt], DoltTableUpdate]
             raise ValueError('Missing tables {}'.format(missing_tables))
 
         for table in tables:
-            logger.info('Reading tables: {}'.format(tables))
+            logger.info('Reading table: {}'.format(table))
             result[table] = reader(table, repo)
 
         return result
@@ -130,11 +132,11 @@ def get_table_reader_diffs(commit_ref: str = None, branch: str = None) -> Callab
             repo.checkout(branch)
 
         from_commit, to_commit = get_from_commit_to_commit(repo, commit_ref)
-        metadata = MetaData(bind=repo.engine)
+        metadata = MetaData(bind=repo.get_engine())
         metadata.reflect()
         table = metadata.tables[table_name]
-        pks_to_drop = get_dropped_pks(repo.engine, table, from_commit, to_commit)
-        result = _read_from_dolt_diff(repo.engine, table, from_commit, to_commit)
+        pks_to_drop = get_dropped_pks(repo.get_engine(), table, from_commit, to_commit)
+        result = _read_from_dolt_diff(repo.get_engine(), table, from_commit, to_commit)
         return pks_to_drop, result
 
     return inner
@@ -201,10 +203,10 @@ def get_table_reader(commit_ref: str = None, branch: str = None) -> Callable[[st
             repo.checkout(branch)
 
         query_commit = commit_ref or list(repo.log().keys())[0]
-        table = get_table_metadata(repo.engine, table_name)
+        table = get_table_metadata(repo.get_engine(), table_name)
         from_commit, to_commit = get_from_commit_to_commit(repo, query_commit)
-        pks_to_drop = get_dropped_pks(repo.engine, table, from_commit, to_commit)
-        result = _read_from_dolt_history(repo.engine, table, query_commit)
+        pks_to_drop = get_dropped_pks(repo.get_engine(), table, from_commit, to_commit)
+        result = _read_from_dolt_history(repo.get_engine(), table, query_commit)
         return pks_to_drop, result
 
     return inner
@@ -262,14 +264,13 @@ def write_to_table(repo: Dolt, table: Table, data: List[dict], commit: bool = Fa
     :return:
     """
     coerced_data = list(clean_types(data))
-    inserts, updates = get_inserts_and_updates(repo.engine, table, coerced_data)
+    inserts, updates = get_inserts_and_updates(repo.get_engine(), table, coerced_data)
     if inserts:
         logger.info('Inserting {} rows'.format(len(inserts)))
-        with repo.engine.connect() as conn:
+        with repo.get_engine().connect() as conn:
             conn.execute(table.insert(), inserts)
 
     # We need to prefix the columns with "_" in order to use bindparam properly
-    from copy import deepcopy
     _updates = deepcopy(updates)
     for dic in _updates:
         for col in list(dic.keys()):
@@ -277,7 +278,7 @@ def write_to_table(repo: Dolt, table: Table, data: List[dict], commit: bool = Fa
 
     if _updates:
         logger.info('Updating {} rows'.format(len(_updates)))
-        with repo.engine.connect() as conn:
+        with repo.get_engine().connect() as conn:
             statement = table.update()
             for pk_col in [col.name for col in table.columns if col.primary_key]:
                 statement = statement.where(table.c[pk_col] == bindparam('_{}'.format(pk_col)))
@@ -310,5 +311,3 @@ def get_inserts_and_updates(engine: Engine, table: Table, data: List[dict]) -> T
     return inserts, updates
 
 
-def hash_row_els(row: dict, cols: List[str]) -> int:
-    return hash(frozenset({col: row[col] for col in cols}.items()))
