@@ -6,14 +6,15 @@ import sqlalchemy
 
 
 @pytest.fixture(scope='session')
-def docker_compose_file(tmpdir_factory, mysql_service_def, postgres_service_def):
+def docker_compose_file(tmpdir_factory, mysql_service_def, postgres_service_def, oracle_service_def):
     compose_file = tmpdir_factory.mktemp('docker_files').join('docker-compose.yml')
 
     compose_conf = {
         'version': '2',
         'services': {
             'mysql': mysql_service_def,
-            'postgres': postgres_service_def
+            'postgres': postgres_service_def,
+            'oracle': oracle_service_def
         }
     }
 
