@@ -30,7 +30,20 @@ def repo_with_table_with_arrays(request, init_empty_test_repo) -> Tuple[Dolt, Ta
     return _test_table_helper(repo, request, DOLT_TABLE_WITH_ARRAYS)
 
 
+@pytest.fixture
+def empty_repo_with_server_process(request, init_empty_test_repo) -> Dolt:
+    repo = init_empty_test_repo
+    _server_helper(repo, request)
+    return repo
+
+
 def _test_table_helper(repo: Dolt, request, metadata: MetaData) -> Tuple[Dolt, Table]:
+    _server_helper(repo, request)
+    metadata.create(repo.get_engine())
+    return repo, metadata
+
+
+def _server_helper(repo: Dolt, request):
     repo.sql_server()
 
     @retry(delay=2, tries=10, exceptions=(
@@ -39,21 +52,17 @@ def _test_table_helper(repo: Dolt, request, metadata: MetaData) -> Tuple[Dolt, T
             sqlalchemy.exc.InterfaceError,
     ))
     def verify_connection():
-        conn = repo.engine.connect()
+        conn = repo.get_engine().connect()
         conn.close()
-        return repo.engine
-
-    engine = verify_connection()
-    metadata.create(engine)
+        return repo.get_engine()
 
     def finalize():
         if repo.server:
             repo.sql_server_stop()
 
+    verify_connection()
     request.addfinalizer(finalize)
 
-    return repo, metadata
-
 
 @pytest.fixture
 def create_dolt_test_data_commits(repo_with_table):
@@ -68,16 +77,17 @@ def create_dolt_test_data_commits(repo_with_table):
     write_to_table(repo, table, TEST_DATA_INITIAL, commit=True)
     write_to_table(repo, table, TEST_DATA_APPEND_SINGLE_ROW, commit=True)
     write_to_table(repo, table, TEST_DATA_APPEND_MULTIPLE_ROWS, commit=True)
+
     # TODO: we currently do not support ON DUPLICATE KEY syntax, so this does the update
     # write_to_table(repo, table, TEST_DATA_UPDATE_SINGLE_ROW, commit=True)
     _query_helper(repo, get_dolt_update_row_statement(table), 'Updated a row')
-    _query_helper(repo, get_dolt_drop_pk_query(table), 'Updated a row')
+    _query_helper(repo, get_dolt_drop_pk_query(table), 'Dropped a row')
 
     return repo, table
 
 
 def _query_helper(repo: Dolt, query, message):
-    with repo.engine.connect() as conn:
+    with repo.get_engine().connect() as conn:
         conn.execute(query)
 
     repo.add(TABLE_NAME)
